@@ -97,7 +97,7 @@ class SchemaPublicManager(SchemaManager):
 class Schema(models.Model):
     """
     Describes a type of NewsItem.  A NewsItem has exactly one Schema,
-    which describes its attributes, via associated SchemaFields.
+    which describes its Attributes, via associated SchemaFields.
 
     nb. to get all NewsItem instances for a Schema, you can do the usual as per
     http://docs.djangoproject.com/en/dev/topics/db/queries/#backwards-related-objects:
@@ -120,8 +120,14 @@ class Schema(models.Model):
         help_text='Bigger number is more important; used for sorting in some places.')
     is_public = models.BooleanField(
         db_index=True, default=False,
-        help_text="Set False if you want only people with the staff cookie to be able to see it.")
-    is_special_report = models.BooleanField(default=False)
+        help_text="Set False if you want only people with the staff cookie to be able to see it.") 
+    is_special_report = models.BooleanField(
+        default=False,
+        help_text="Whether to use the schema_detail_special_report view for these items, eg. for displaying items that have a known general Location but not a specific point.")
+
+    is_event = models.BooleanField(
+        default=False,
+        help_text="Whether these items are (potentially) future events rather than news in the past.")
 
     can_collapse = models.BooleanField(
         default=False,
@@ -131,6 +137,11 @@ class Schema(models.Model):
         default=False,
         help_text="Whether to show a detail page for NewsItems of this schema, or redirect to the NewsItem's source URL instead.")
 
+    allow_comments = models.BooleanField(
+        default=False,
+        help_text="Whether to allow users to add comments to NewsItems of the schema. Only applies to items with detail page."
+    )
+
     allow_charting = models.BooleanField(
         default=False,
         help_text="Whether aggregate charts are displayed on the home page of this Schema")
@@ -168,13 +179,13 @@ class Schema(models.Model):
     short_description = models.TextField(blank=True, default='')
     summary = models.TextField(blank=True, default='')
     source = models.TextField(blank=True, default='',
-                              help_text='Where this information came from, eg. a URL.')
-    grab_bag_headline = models.CharField(max_length=128, blank=True, default='')
-    grab_bag = models.TextField(blank=True, default='')  # TODO: what does this field mean?
-    short_source = models.CharField(max_length=128, blank=True, default='')
+                              help_text='Where this information came from, as one or more URLs, one per line.')
+    grab_bag_headline = models.CharField(max_length=128, blank=True, default='') # Remove? #232
+    grab_bag = models.TextField(blank=True, default='')  # Remove? #232
+    short_source = models.CharField(max_length=128, blank=True, default='One-line description of where this information came from.')
     update_frequency = models.CharField(max_length=64, blank=True, default='',
                                         choices=FREQUENCY_CHOICES)
-    intro = models.TextField(blank=True, default='')
+    intro = models.TextField(blank=True, default='')  # Remove? #232
 
     class Meta:
         ordering = ('name',)
@@ -373,7 +384,7 @@ class Location(models.Model):
         return self.name
 
     def url(self):
-        return urlresolvers.reverse('ebpub-location-timeline',
+        return urlresolvers.reverse('ebpub-location-recent',
                                     args=(self.location_type.slug, self.slug))
 
     def rss_url(self):
@@ -595,11 +606,10 @@ class NewsItemQuerySet(models.query.GeoQuerySet):
         """
         Returns a dictionary mapping {item_date: count}.
         """
-        # TODO: values + annotate doesn't seem to play nice with GeoQuerySet
-        # at the moment. This is the changeset where it broke:
-        # http://code.djangoproject.com/changeset/10326
         from django.db.models.query import QuerySet
         qs = QuerySet.values(self, 'item_date').annotate(count=models.Count('id'))
+        # Turn off ordering, as that breaks Count; see https://docs.djangoproject.com/en/dev/topics/db/aggregation/#interaction-with-default-ordering-or-order-by
+        qs = qs.order_by()
         return dict([(v['item_date'], v['count']) for v in qs])
 
     def top_lookups(self, schema_field, count):
@@ -736,12 +746,17 @@ class NewsItem(models.Model):
     item_date = models.DateField(
         db_index=True,
         help_text='Date (no time) this Item occurred, or was published on the original source site.')  # TODO: default to now()
+
+    # automatic last modification tracking.  Note: if changing only attributes, the the
+    # NewsItem should also be save()'d to update last_modification when complete. 
+    last_modification = models.DateTimeField(db_index=True, auto_now=True)
+    
     location = models.GeometryField(blank=True, null=True, spatial_index=True,
                                     help_text="Coordinates where this news occurred.")
     location_name = models.CharField(max_length=255,
                                      help_text="Human-readable address or name of place where this news item occurred.")
     location_object = models.ForeignKey(Location, blank=True, null=True,
-                                        help_text="Optional reference to a Location where this item occurred")
+                                        help_text="Optional reference to a Location where this item occurred, for use when we know the general area but not specific coordinates.")
     block = models.ForeignKey(Block, blank=True, null=True,
                               help_text="Optional reference to a Block. Not really used")
 
@@ -806,7 +821,7 @@ class AttributeForTemplate(object):
             elif (isinstance(self.raw_value, list) and self.raw_value
                   and isinstance(self.raw_value[0], Lookup)):
                 self.values = self.raw_values
-            elif self.raw_value == '':
+            elif self.raw_value is None or self.raw_value == '':
                 self.values = []
             elif self.sf.is_many_to_many_lookup():
                 try:
@@ -834,7 +849,6 @@ class AttributeForTemplate(object):
         if self.is_filter:
             from ebpub.db.schemafilters import FilterChain
             chain = FilterChain(schema=self.sf.schema)
-            chain.base_url = self.sf.schema.url()
             if self.is_lookup:
                 urls = [chain.replace(self.sf, look).make_url() if look else None
                         for look in self.values]
@@ -965,19 +979,23 @@ class LookupManager(models.Manager):
 class Lookup(models.Model):
     schema_field = models.ForeignKey(SchemaField)
     name = models.CharField(max_length=255)
-    # `code` is the optional internal code to use during retrieval.
-    # For example, in scraping Chicago crimes, we use the crime type code
+    code = models.CharField(
+        max_length=255, blank=True,
+        help_text='Optional internal code to use for retrieval if `name` is modified from the original data source, eg. to make `name` prettier.')
+    # ... For example, in scraping Chicago crimes, we use the crime type code
     # to find the appropriate crime type in this table. We can't use `name`
     # in that case, because we've massaged `name` to use a "prettier"
     # formatting than exists in the data source.
-    code = models.CharField(max_length=255, blank=True)
+
     slug = models.SlugField(max_length=32, db_index=True)
     description = models.TextField(blank=True)
 
     objects = LookupManager()
 
     class Meta:
-        unique_together = (('slug', 'schema_field'),)
+        unique_together = (('slug', 'schema_field'),
+                           ('code', 'schema_field'),
+                          )
         ordering = ('slug',)
 
     def natural_key(self):
@@ -1087,3 +1105,17 @@ class DataUpdate(models.Model):
     def total_time(self):
         return self.update_finish - self.update_start
 
+def get_city_locations():
+    """
+    If we have configured multiple_cities, find all Locations
+    of the city_location_type.
+    Otherwise, empty query set.
+    """
+    from ebpub.metros.allmetros import get_metro
+    metro = get_metro()
+    if metro['multiple_cities']:
+        cities = Location.objects.filter(location_type__slug=metro['city_location_type'])
+        cities = cities.exclude(location_type__name__startswith='Unknown')
+        return cities
+    else:
+        return Location.objects.filter(id=None)
