@@ -21,12 +21,12 @@ from ebpub.db.utils import populate_attributes_if_needed
 from ebpub.utils.bunch import bunch, bunchlong, stride
 from ebpub.metros.allmetros import METRO_LIST, get_metro
 from django import template
-from django.conf import settings
+from django.core.cache import cache
 from django.template.defaultfilters import stringfilter
 from django.template.loader import select_template
-from django.conf import settings
 from ebpub.db.utils import today
 import datetime
+import re
 
 register = template.Library()
 
@@ -35,22 +35,12 @@ register.filter('bunchlong', bunchlong)
 register.filter('stride', stride)
 
 def METRO_NAME():
-    return get_metro()['metro_name']
+    name = get_metro()['metro_name']
+    if name[0] != name[0].upper:
+        name = name.title()
+    return name
 register.simple_tag(METRO_NAME)
 
-def SHORT_NAME():
-    return settings.SHORT_NAME
-register.simple_tag(SHORT_NAME)
-
-def STATE_ABBREV():
-    return get_metro()['state']
-register.simple_tag(STATE_ABBREV)
-
-def EB_SUBDOMAIN():
-    # misnamed, it's actually the full domain.
-    return settings.EB_DOMAIN
-register.simple_tag(EB_SUBDOMAIN)
-
 def isdigit(value):
     return value.isdigit()
 isdigit = stringfilter(isdigit)
@@ -257,6 +247,7 @@ class NewsItemListBySchemaNode(template.Node):
             'place': context.get('place'),
             'is_block': context.get('is_block'),
             'block_radius': context.get('block_radius'),
+            'today': today,
         }))
 
 def do_newsitem_list_by_schema(parser, token):
@@ -276,3 +267,78 @@ register.tag('newsitem_list_by_schema', do_newsitem_list_by_schema)
 def contains(value, arg):
     return arg in value
 register.filter('contains', contains)
+
+
+class SearchPlaceholderNode(template.Node):
+    """
+    See do_search_placeholder()
+    """
+    def __init__(self, prefix, var_name):
+        self.prefix = prefix.strip()
+        self.var_name = var_name.strip()
+
+    def render(self, context):
+        cachekey = 'SearchPlaceholderNode'
+        result = cache.get(cachekey)
+        if result is None:
+            from ebpub.db.models import LocationType
+            types = LocationType.objects.filter(is_significant=True)
+            types = list(types.order_by('name').values('name'))
+            names = ['address'] + [loctype['name'].lower() for loctype in types]
+            if len(names) > 3:
+                # like "foo, bar, baz, ..."
+                result = u'%s, ...' % (u', '.join(names[:3]))
+            elif len(names) > 2:
+                # like "foo, bar, or baz"
+                result = u'%s, or %s' % (u', '.join(names[:-1]), names[-1])
+            elif len(names) == 2:
+                # like "foo or bar"
+                result = u'%s or %s' % tuple(names)
+            else:
+                result = names[0]
+            cache.set(cachekey, result, 60 * 60)
+        if self.prefix:
+            result = u'%s %s' % (self.prefix, result)
+        else:
+            # By default we want just the 1st letter forced caps,
+            # and only when there's no prefix.
+            result = result[0].upper() + result[1:]
+        context[self.var_name] = result
+        return ''
+
+def do_search_placeholder(parser, token):
+    """
+    Stores in the context a list of LocationTypes,
+    plus 'address', with an optional prefix.
+
+    Useful for search form widgets where we want to use this as
+    placeholder text on the input, and need to write the same string
+    over and over because javascript will be checking for the
+    placeholder text, restoring it, etc.
+
+    Example::
+
+      {% set_search_placeholder "Some prefix" as some_var %}
+      <p>{{ some_var }}</p>
+
+    This will output in the template::
+
+      <p>Some prefix address, ZIP, or neighborhood</p>
+    """
+    # In Django 1.4, this could become an assignment_tag as per
+    # https://docs.djangoproject.com/en/dev/howto/custom-template-tags/#howto-custom-template-tags-assignment-tags
+    # This version uses a regular expression to parse tag contents.
+    try:
+        # Splitting by None == splitting by spaces.
+        tag_name, arg = token.contents.split(None, 1)
+    except ValueError:
+        raise template.TemplateSyntaxError("%r tag requires arguments" % token.contents.split()[0])
+    m = re.search(r'(.*?) as (\w+)', arg)
+    if not m:
+        raise template.TemplateSyntaxError("%r tag had invalid arguments" % tag_name)
+    prefix, var_name = m.groups()
+    if not (prefix[0] == prefix[-1] and prefix[0] in ('"', "'")):
+        raise template.TemplateSyntaxError("%r tag's argument should be in quotes" % tag_name)
+    return SearchPlaceholderNode(prefix[1:-1], var_name)
+
+register.tag('set_search_placeholder', do_search_placeholder)
