@@ -21,11 +21,11 @@ Unit tests for db.views.
 """
 
 from django.core import urlresolvers
-from django.test import TestCase
 from django.utils import simplejson
 from ebpub.db import models
 from ebpub.db.urlresolvers import filter_reverse
 from ebpub.db.views import BadAddressException
+from ebpub.utils.django_testcase_backports import TestCase
 import datetime
 import logging
 import mock
@@ -34,18 +34,22 @@ import urllib
 
 class BaseTestCase(TestCase):
 
+    _logger_keys = ('django.request',)
+
     def setUp(self):
         # Don't log 404 warnings, we expect a lot of them during these
         # tests.
-        logger = logging.getLogger('django.request')
-        self._previous_level = logger.getEffectiveLevel()
-        logger.setLevel(logging.ERROR)
+        self._previous_levels = {}
+        for key in self._logger_keys:
+            logger = logging.getLogger(key)
+            self._previous_levels[key] = logger.getEffectiveLevel()
+            logger.setLevel(logging.ERROR)
 
     def tearDown(self):
         # Restore old log level.
-        logger = logging.getLogger('django.request')
-        logger.setLevel(self._previous_level)
-
+        for key in self._logger_keys:
+            logger = logging.getLogger(key)
+            logger.setLevel(self._previous_levels[key])
 
 class ViewTestCase(BaseTestCase):
     "Unit tests for views.py."
@@ -82,11 +86,11 @@ class ViewTestCase(BaseTestCase):
         self.assertContains(response, 'crime title 1')
         self.assertContains(response, 'http://X')
 
-    def test_location_redirect(self):
-        # redirect to neighborhoods by default
-        response = self.client.get('/locations/')
-        self.assertEqual(response.status_code, 301)
-        self.assertEqual(response['Location'], 'http://testserver/locations/neighborhoods/')
+    def test_locationtype_list_redirect(self):
+        with self.settings(DEFAULT_LOCTYPE_SLUG='thingies'):
+            response = self.client.get('/locations/')
+            self.assertEqual(response.status_code, 301)
+            self.assertEqual(response['Location'], 'http://testserver/locations/thingies/')
 
     def test_schema_detail(self):
         response = self.client.get('/crime/')
@@ -111,11 +115,12 @@ class LocationDetailTestCase(BaseTestCase):
     @mock.patch('ebpub.db.views.today')
     def test_location_timeline(self, mock_today):
         mock_today.return_value = datetime.date(2006, 9, 26)
-        url = urlresolvers.reverse('ebpub-location-timeline',
+        url = urlresolvers.reverse('ebpub-location-recent',
                                    args=['neighborhoods', 'hood-1'])
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
-        self.assertEqual(len(response.context['newsitem_list']), 2)
+        self.assertEqual(len(response.context['newsitem_list']), 1)
+        self.assertEqual(response.context['newsitem_list'][0].title, 'crime title 1')
 
     def test_location_overview(self):
         url = urlresolvers.reverse('ebpub-location-overview',
@@ -159,8 +164,10 @@ class TestAjaxViews(BaseTestCase):
         self.assertEqual(response.status_code, 404)
 
 
+    @mock.patch('ebpub.db.views.today')
     @mock.patch('ebpub.db.views.FilterChain')
-    def test_ajax_place_date_chart__location(self, mock_chain):
+    def test_ajax_place_date_chart__location(self, mock_chain, mock_today):
+        mock_today.return_value = datetime.date(2006, 11, 10)
         # Hack so isinstance(mock_chain(), FilterChain) works
         from ebpub.db import schemafilters
         mock_chain.return_value = mock.Mock(spec=schemafilters.FilterChain)
@@ -171,11 +178,10 @@ class TestAjaxViews(BaseTestCase):
         url = urlresolvers.reverse('ajax-place-date-chart') + '?s=1&pid=b:1000.8'
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
-        self.assertEqual(response.context['date_chart']['total_count'], 1)
-        self.assertEqual(len(response.context['date_chart']['dates']), 8)
-        import datetime
+        self.assertEqual(response.context['date_chart']['total_count'], 2)
+        self.assertEqual(len(response.context['date_chart']['dates']), 10)
         self.assertEqual(response.context['date_chart']['dates'][-1],
-                         {'date': datetime.date(2006, 11, 8), 'count': 1})
+                         {'date': datetime.date(2006, 11, 8), 'count': 2})
 
 
     @mock.patch('ebpub.db.views.FilterChain')
@@ -509,9 +515,9 @@ class TestSchemaFilterView(BaseTestCase):
         # filtering after that.)
         # TODO: this is pretty brittle. Worth it?
         mock_qs = mock.Mock()
-        mock_qs.order_by.return_value = mock_qs
+        mock_qs.filter.return_value = mock_qs
         newsitem = models.NewsItem.objects.all()[0]
-        mock_qs.filter.return_value = [newsitem] * 100
+        mock_qs.order_by.return_value = [newsitem] * 100
 
         mock_chain.return_value = mock_chain
         mock_chain.apply.return_value = mock_qs
