@@ -16,7 +16,6 @@
 #   along with ebpub.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from django import template
 from django.conf import settings
 from django.contrib.gis.shortcuts import render_to_kml
 from django.core.cache import cache
@@ -26,11 +25,11 @@ from django.http import Http404
 from django.http import HttpResponse
 from django.http import HttpResponseRedirect, HttpResponsePermanentRedirect
 from django.shortcuts import render_to_response, get_object_or_404
-from django.template.loader import select_template
 from django.utils import simplejson
 from django.utils.cache import patch_response_headers
 from django.utils.datastructures import SortedDict
 from django.views.decorators.cache import cache_page
+from django.views.decorators.csrf import csrf_protect
 from ebpub.constants import HIDE_ADS_COOKIE_NAME, HIDE_SCHEMA_INTRO_COOKIE_NAME
 from ebpub.db import breadcrumbs
 from ebpub.db import constants
@@ -43,10 +42,9 @@ from ebpub.db.schemafilters import BadDateException
 
 from ebpub.db.utils import populate_attributes_if_needed, populate_schema, today
 from ebpub.db.utils import url_to_place
-from ebpub.geocoder import SmartGeocoder, AmbiguousResult, DoesNotExist, InvalidBlockButValidStreet
 from ebpub.db.utils import get_place_info_for_request
 from ebpub import geocoder
-from ebpub.geocoder.parser.parsing import normalize, ParsingError
+from ebpub.geocoder.parser.parsing import normalize
 from ebpub.metros.allmetros import get_metro
 from ebpub.openblockapi.views import api_items_geojson
 from ebpub.preferences.models import HiddenSchema
@@ -71,6 +69,8 @@ logger = logging.getLogger('ebpub.db.views')
 
 
 def get_date_chart_agg_model(schemas, start_date, end_date, agg_model, kwargs=None):
+    """start_date and end_date are *inclusive*.
+    """
     kwargs = kwargs or {}
     counts = {}
     for agg in agg_model.objects.filter(schema__id__in=[s.id for s in schemas], date_part__range=(start_date, end_date), **kwargs):
@@ -81,7 +81,8 @@ def get_date_chart(schemas, start_date, end_date, counts):
     """
     Returns a list that's used to display a date chart for the given
     schemas. Note that start_date and end_date should be datetime.date objects,
-    NOT datetime.datetime objects.
+    NOT datetime.datetime objects, and they are *inclusive*,
+    i.e. the resulting chart will include both start_date and end_date.
 
     counts should be a nested dictionary: {schema_id: {date: count}}
 
@@ -126,27 +127,6 @@ def block_bbox(block, radius):
     return (env[0], env[2], env[1], env[3])
 
 
-def _map_popups(ni_list):
-    """
-    Given a list of newsitems, return a list of lists
-    of the form [newsitem_id, popup_html, schema_name]
-    """
-    schemas = list(set([ni.schema for ni in ni_list]))
-    populate_attributes_if_needed(ni_list, schemas)
-    result = []
-    current_schema = current_template = None
-    for ni in ni_list:
-        schema = ni.schema
-        if current_schema != schema:
-            # This goes faster if ni_list is sorted by schema.
-            template_list = ['db/snippets/newsitem_popup_list/%s.html' % schema.slug,
-                             'db/snippets/newsitem_popup_list.html',
-                             ]
-            current_template = select_template(template_list)
-            current_schema = schema
-        html = current_template.render(template.Context({'newsitem': ni, 'schema': schema, }))
-        result.append([ni.id, html, schema.name.title()])
-    return result
 
 
 ##############
@@ -176,7 +156,11 @@ def ajax_place_lookup_chart(request):
 
 def ajax_place_date_chart(request):
     """
-    Returns HTML fragment -- expects request.GET['pid'] and request.GET['s'] (a Schema ID).
+    Returns HTML fragment containing a chart of how many news items
+    were added for each day over a short period (length defined by
+    constants.DAYS_SHORT_AGGREGATE_TIMEDELTA).
+
+    Expects request.GET['pid'] and request.GET['s'] (a Schema ID).
     """
     try:
         schema = Schema.public_objects.get(id=int(request.GET['s']))
@@ -185,9 +169,30 @@ def ajax_place_date_chart(request):
     filters = FilterChain(request=request, schema=schema)
     filters.add_by_place_id(request.GET.get('pid', ''))
     qs = filters.apply()
-    # TODO: Ignore future dates
-    end_date = qs.order_by('-item_date').values('item_date')[0]['item_date']
-    start_date = end_date - datetime.timedelta(days=settings.DEFAULT_DAYS)
+
+    # These charts are used on eg. the place overview page; there,
+    # they should be smaller than the ones on the schema_detail view;
+    # we don't have room for a full 30 days.
+    date_span = constants.DAYS_SHORT_AGGREGATE_TIMEDELTA
+    if schema.is_event:
+        # Soonest span that includes some.
+        try:
+            qs = qs.filter(item_date__gte=today()).order_by('item_date', 'id')
+            first_item = qs.values('item_date')[0]
+            start_date = first_item['item_date']
+        except IndexError:  # No matching items.
+            start_date = today()
+        end_date = today() + date_span
+    else:
+        # Most recent span that includes some.
+        try:
+            qs = qs.filter(item_date__lte=today()).order_by('-item_date', '-id')
+            last_item = qs.values('item_date')[0]
+            end_date = last_item['item_date']
+        except IndexError:  # No matching items.
+            end_date = today()
+        start_date = end_date - date_span
+
     filters.add('date', start_date, end_date)
     counts = filters.apply().date_counts()
     date_chart = get_date_chart([schema], start_date, end_date, {schema.id: counts})[0]
@@ -197,6 +202,7 @@ def ajax_place_date_chart(request):
         'filters': filters,
     })
 
+
 def newsitems_geojson(request):
     """Get a list of newsitems, optionally filtered for one place ID
     and/or one schema slug.
@@ -218,9 +224,6 @@ def newsitems_geojson(request):
 
     nid = request.GET.get('newsitem', '')
 
-    cache_seconds = 60 * 5
-    cache_key = 'newsitem_geojson_%s_%s_%s' % (pid, nid, schema)
-
     newsitem_qs = NewsItem.objects.all()
     if nid:
         newsitem_qs = newsitem_qs.filter(id=nid)
@@ -247,19 +250,16 @@ def newsitems_geojson(request):
 
         # Put a hard limit on the number of newsitems, and throw away
         # older items.
-        newsitem_qs = newsitem_qs.select_related().order_by('-pub_date')
+        newsitem_qs = newsitem_qs.select_related().order_by('-item_date', '-id')
         newsitem_qs = newsitem_qs[:constants.NUM_NEWS_ITEMS_PLACE_DETAIL]
 
     # Done preparing the query; cache based on the raw SQL
     # to be sure we capture everything that matters.
-    cache_key += hashlib.md5(str(newsitem_qs.query)).hexdigest()
+    cache_seconds = 60 * 5
+    cache_key = 'newsitem_geojson:' + _make_cache_key_from_queryset(newsitem_qs)
     output = cache.get(cache_key, None)
     if output is None:
-        # Re-sort by schema type.
-        # This is an optimization for map_popups().
-        # We can't do it in the qs because we want to first slice the qs
-        # by date, and we can't call order_by() after a slice.
-        newsitem_list = sorted(newsitem_qs, key=lambda ni: ni.schema.id)
+        newsitem_list = list(newsitem_qs)
         output = api_items_geojson(newsitem_list)
         cache.set(cache_key, output, cache_seconds)
 
@@ -267,6 +267,11 @@ def newsitems_geojson(request):
     patch_response_headers(response, cache_timeout=60 * 5)
     return response
 
+def _make_cache_key_from_queryset(qs):
+    cache_key = 'query:'
+    cache_key += hashlib.md5(str(qs.query)).hexdigest()
+    return cache_key
+
 @cache_page(60 * 60)
 def place_kml(request, *args, **kwargs):
     place = url_to_place(*args, **kwargs)
@@ -395,6 +400,7 @@ def search(request, schema_slug=''):
     lt_list = LocationType.objects.filter(is_significant=True).order_by('name')
     return eb_render(request, 'db/search_error.html', {'query': q, 'locationtype_list': lt_list})
 
+@csrf_protect
 def newsitem_detail(request, schema_slug, newsitem_id):
     ni = get_object_or_404(NewsItem.objects.select_related(), id=newsitem_id,
                            schema__slug=schema_slug)
@@ -505,7 +511,7 @@ def schema_detail(request, slug):
             date_chart = {}
             start_date = end_date = None
         else:
-            start_date = end_date - datetime.timedelta(days=constants.NUM_DAYS_AGGREGATE)
+            start_date = end_date - constants.DAYS_AGGREGATE_TIMEDELTA
             date_chart = get_date_chart_agg_model([s], start_date, end_date, AggregateDay)[0]
             latest_dates = [date['date'] for date in date_chart['dates'] if date['count']]
 
@@ -548,7 +554,7 @@ def schema_detail(request, slug):
     else:
         date_chart = {}
         latest_dates = schemafield_list = lookup_list = location_chartfield_list = ()
-        ni_list = list(NewsItem.objects.filter(schema__id=s.id).order_by('-item_date')[:30])
+        ni_list = list(NewsItem.objects.filter(schema__id=s.id).order_by('-item_date', '-id')[:30])
         populate_schema(ni_list, s)
         populate_attributes_if_needed(ni_list, [s])
 
@@ -584,6 +590,9 @@ def schema_detail(request, slug):
     return eb_render(request, templates_to_try, context)
 
 def schema_detail_special_report(request, schema):
+    """
+    For display of schemas where is_special_report=True.
+    """
     ni_list = NewsItem.objects.filter(schema__id=schema.id)
     populate_schema(ni_list, schema)
     populate_attributes_if_needed(ni_list, [schema])
@@ -605,12 +614,68 @@ def schema_detail_special_report(request, schema):
         'bodyid': schema.slug,
     })
 
-def schema_about(request, slug):
-    s = get_object_or_404(get_schema_manager(request), slug=slug)
-    context = {'schema': s, 'bodyid': slug, 'bodyclass': 'schema-about',}
-    context['breadcrumbs'] = breadcrumbs.schema_about(context)
-    return eb_render(request, 'db/schema_about.html', context)
 
+def schema_filter_geojson(request, slug, args_from_url):
+    s = get_object_or_404(get_schema_manager(request), slug=slug, is_special_report=False)
+    if not s.allow_charting:
+        return HttpResponse(status=404)
+
+    filter_sf_list = list(SchemaField.objects.filter(schema__id=s.id, is_filter=True).order_by('display_order'))
+    textsearch_sf_list = list(SchemaField.objects.filter(schema__id=s.id, is_searchable=True).order_by('display_order'))
+
+    # Use SortedDict to preserve the display_order.
+    filter_sf_dict = SortedDict([(sf.name, sf) for sf in filter_sf_list] + [(sf.name, sf) for sf in textsearch_sf_list])
+
+    # Determine what filters to apply, based on path and/or query string.
+    filterchain = FilterChain(request=request, schema=s)
+    try:
+        filterchain.update_from_request(args_from_url, filter_sf_dict)
+        filters_need_more = filterchain.validate()
+    except FilterError:
+        return HttpResponse(status=400)
+    except BadAddressException:
+        return HttpResponse(status=400)
+    except BadDateException:
+        return HttpResponse(status=400)
+
+    if filters_need_more:
+        return HttpResponse(status=400)
+
+
+    # If there isn't a date filter, add some dates to the queryset,
+    # but NOT to the filterchain, because need to give the user the
+    # option of choosing dates.
+    qs, start_date, end_date = _default_date_filtering(filterchain)
+
+    if s.is_event:
+        qs = qs.order_by('item_date', 'id')
+    else:
+        qs = qs.order_by('-item_date', '-id')
+
+    page = request.GET.get('page', None)
+    if page is not None:
+        try:
+            page = int(page)
+            idx_start = (page - 1) * constants.FILTER_PER_PAGE
+            idx_end = page * constants.FILTER_PER_PAGE
+            # Get one extra, so we can tell whether there's a next page.
+            idx_end += 1
+        except ValueError:
+            return HttpResponse('Invalid Page', status=400)
+    else:
+        idx_start, idx_end = 0, 1000
+    qs = qs[idx_start:idx_end]
+
+    cache_key = 'schema_filter_geojson:' + _make_cache_key_from_queryset(qs)
+    cache_seconds = 60 * 5
+    output = cache.get(cache_key, None)
+    if output is None:
+        output = api_items_geojson(list(qs))
+        cache.set(cache_key, output, cache_seconds)
+
+    response = HttpResponse(output, mimetype="application/javascript")
+    patch_response_headers(response, cache_timeout=60 * 5)
+    return response
 
 def schema_filter(request, slug, args_from_url):
     """
@@ -667,17 +732,13 @@ def schema_filter(request, slug, args_from_url):
     if new_url != request.get_full_path():
         return HttpResponseRedirect(new_url)
 
-    # Finally, filter the newsitems.
-    qs = filterchain.apply().order_by('-item_date')
+    # Make the queryset, with default date filtering if needed.
+    qs, start_date, end_date = _default_date_filtering(filterchain)
 
-    date_filter = filterchain.get('date') or filterchain.get('pubdate')
-    if date_filter:
-        start_date = date_filter.start_date
-        end_date = date_filter.end_date
+    if s.is_event:
+        qs = qs.order_by('item_date', 'id')
     else:
-        start_date = s.min_date
-        end_date = today()
-        qs = qs.filter(item_date__gte=start_date, item_date__lte=end_date)
+        qs = qs.order_by('-item_date', '-id')
 
     context['newsitem_qs'] = qs
 
@@ -703,6 +764,9 @@ def schema_filter(request, slug, args_from_url):
                 has_more = True
             else:
                 has_more = False
+            # Note we ordered by -total to get the top values, but since we don't
+            # display the count, that ordering is nonsensical to the user.
+            top_values = sorted(top_values, key = lambda x: x.lookup.name)
             lookup_list.append({'sf': sf, 'top_values': top_values, 'has_more': has_more})
 
     # Get the list of LocationTypes if a location filter has *not* been applied.
@@ -751,6 +815,20 @@ def schema_filter(request, slug, args_from_url):
                 'default_zoom': settings.DEFAULT_MAP_ZOOM,
                 })
 
+    # Try to provide a link to larger map, but don't worry about it
+    # if there is no richmap app hooked in...
+    try:
+        large_map_url = filterchain.make_url(base_url=reverse('bigmap_filter', args=(slug,)))
+        if filterchain.get('date') is None:
+            # force a date range
+            large_map_url += '?end_date=' + ni_list[0].pub_date.strftime("%m/%d/%Y") 
+
+        context.update({
+            'large_map_url': large_map_url
+        })
+    except:
+        pass
+
     context.update({
         'newsitem_list': ni_list,
 
@@ -777,6 +855,36 @@ def schema_filter(request, slug, args_from_url):
     return eb_render(request, 'db/filter.html', context)
 
 
+def _default_date_filtering(filterchain):
+    """
+    Make sure we do some date limiting, but don't force a
+    DateFilter into the filterchain, because that would prevent
+    users from choosing dates.
+    """
+    schema = filterchain['schema'].schema
+    date_filter = filterchain.get('date') or filterchain.get('pubdate')
+    qs = filterchain.apply()
+    if date_filter:
+        start_date = date_filter.start_date
+        end_date = date_filter.end_date
+    else:
+        if schema.is_event:
+            start_date = today()
+            end_date = start_date + datetime.timedelta(days=30)
+        else:
+            start_date = schema.min_date
+            end_date = today()
+        qs = qs.filter(item_date__gte=start_date,
+                       item_date__lte=end_date)
+    return qs, start_date, end_date
+
+def location_type_list(request):
+    """
+    Default view of /locations; just redirect to the default loc type.
+    """
+    url = reverse('ebpub-loc-type-detail', args=(settings.DEFAULT_LOCTYPE_SLUG,))
+    return HttpResponsePermanentRedirect(url)
+
 def location_type_detail(request, slug):
     lt = get_object_or_404(LocationType, slug=slug)
     order_by = get_metro()['multiple_cities'] and ('city', 'display_order') or ('display_order',)
@@ -794,10 +902,11 @@ def location_type_detail(request, slug):
 
 
 def city_list(request):
+    city_type_slug = get_metro()['city_location_type']
     cities_with_streets = set([City.from_norm_name(c['city']).slug
-                               for c in Street.objects.distinct().values('city')])
+                               for c in Street.objects.order_by().distinct().values('city')])
     all_cities = [City.from_norm_name(v['slug']) for v in
-                  Location.objects.filter(location_type__slug='cities').values('slug', 'name').order_by('name')]
+                  Location.objects.filter(location_type__slug=city_type_slug).values('slug', 'name').order_by('name')]
 
     all_cities = [city for city in all_cities if city.slug.strip()]
     return eb_render(request, 'db/city_list.html',
@@ -816,6 +925,7 @@ def street_list(request, city_slug):
         'street_list': streets,
         'city': city,
         'bodyclass': 'street-list',
+        'example_loctype': LocationType.objects.get(slug=settings.DEFAULT_LOCTYPE_SLUG).plural_name,
     }
     context['breadcrumbs'] = breadcrumbs.street_list(context)
     return eb_render(request, 'db/street_list.html', context)
@@ -857,11 +967,21 @@ def _place_detail_normalize_url(request, *args, **kwargs):
 
 
 def place_detail_timeline(request, *args, **kwargs):
+    """
+    Recent news OR upcoming events for the given Location or Block.
+    """
     context, response = _place_detail_normalize_url(request, *args, **kwargs)
     if response is not None:
         return response
+
+    show_upcoming = kwargs.get('show_upcoming')
     schema_manager = get_schema_manager(request)
-    context['breadcrumbs'] = breadcrumbs.place_detail_timeline(context)
+
+    if show_upcoming:
+        context['breadcrumbs'] = breadcrumbs.place_detail_upcoming(context)
+    else:
+        context['breadcrumbs'] = breadcrumbs.place_detail_timeline(context)
+
     is_latest_page = True
     # Check the query string for the max date to use. Otherwise, fall
     # back to today.
@@ -875,15 +995,26 @@ def place_detail_timeline(request, *args, **kwargs):
 
     filterchain = FilterChain(request=request, context=context)
     filterchain.add('location', context['place'])
-    # As an optimization, limit the NewsItems to those published in the
-    # last few days.
-    start_date = end_date - datetime.timedelta(days=settings.DEFAULT_DAYS)
-    filterchain.add('pubdate', start_date, end_date)
+    # As an optimization, limit the NewsItems to those on the
+    # last (or next) few days.
+    # And only fetch for relevant schemas - either event-ish or not.
+    if show_upcoming:
+        s_list = schema_manager.filter(is_event=True)
+        start_date = end_date
+        end_date = start_date + datetime.timedelta(days=settings.DEFAULT_DAYS)
+        order_by = 'item_date_date'
+    else:
+        s_list = schema_manager.filter(is_event=False)
+        start_date = end_date - datetime.timedelta(days=settings.DEFAULT_DAYS)
+        order_by = '-item_date_date'
+
+    filterchain.add('schema', list(s_list))
+    filterchain.add('date', start_date, end_date)
     newsitem_qs = filterchain.apply().select_related()
     # TODO: can this really only be done via extra()?
     newsitem_qs = newsitem_qs.extra(
-        select={'pub_date_date': 'date(db_newsitem.pub_date)'},
-        order_by=('-pub_date_date', '-schema__importance', 'schema')
+        select={'item_date_date': 'date(db_newsitem.item_date)'},
+        order_by=(order_by, '-schema__importance', 'schema')
     )[:constants.NUM_NEWS_ITEMS_PLACE_DETAIL]
 
     # We're done filtering, so go ahead and do the query, to
@@ -891,10 +1022,10 @@ def place_detail_timeline(request, *args, **kwargs):
     # per http://docs.djangoproject.com/en/dev/topics/db/optimization
     ni_list = list(newsitem_qs)
     schemas_used = list(set([ni.schema for ni in ni_list]))
-    s_list = schema_manager.filter(is_special_report=False, allow_charting=True).order_by('plural_name')
+    s_list = s_list.filter(is_special_report=False, allow_charting=True).order_by('plural_name')
     populate_attributes_if_needed(ni_list, schemas_used)
     if ni_list:
-        next_day = ni_list[-1].pub_date - datetime.timedelta(days=1)
+        next_day = ni_list[-1].item_date - datetime.timedelta(days=1)
     else:
         next_day = None
 
@@ -910,6 +1041,7 @@ def place_detail_timeline(request, *args, **kwargs):
         'bodyclass': 'place-detail-timeline',
         'bodyid': context.get('place_type') or '',
         'filters': filterchain,
+        'show_upcoming': show_upcoming,
     })
 
 
@@ -955,35 +1087,51 @@ def _preconfigured_map(context):
     # TODO filtering? via api? see ticket #121
     ###########################
     
-    # single news item ? 
-    layer_params = {}
-    item = context.get('newsitem')
-    if item is not None: 
-        layer_params['newsitem'] = item.id
+    filters = context.get('filters', None)
+    if filters is not None and (filters.schema is not None and not isinstance(filters.schema, list)):
+        base_url = reverse('ebpub-schema-filter-geojson', args=(context['schema'].slug,))
+        layer_url = filters.make_url(base_url=base_url)
+        layer_params = {}
+        if 'page_number' in context: 
+            layer_params['page'] = context['page_number']
+        items_layer = {
+            'url': layer_url,
+            'params': layer_params,
+            'title': "Custom Filter" ,
+            'visible': True
+        }
+    else:
+        # make up an api layer from the context 
+    
+        # single news item ? 
+        layer_params = {}
+        item = context.get('newsitem')
+        if item is not None: 
+            layer_params['newsitem'] = item.id
 
-    # restricted to place?
-    for key in ['pid']:
-        val = context.get(key)
-        if val is not None: 
-            layer_params[key] = val
+        # restricted to place?
+        for key in ['pid']:
+            val = context.get(key)
+            if val is not None: 
+                layer_params[key] = val
 
-    # restricted date range ?
-    for key in ['start_date', 'end_date']:
-        val = context.get(key)
-        if val is not None: 
-            layer_params[key] = val.strftime('%Y/%m/%d')
+        # restricted date range ?
+        for key in ['start_date', 'end_date']:
+            val = context.get(key)
+            if val is not None: 
+                layer_params[key] = val.strftime('%Y/%m/%d')
 
-    # restricted by schema ?
-    schema_slug = context.get('schema_slug')
-    if schema_slug is not None: 
-        layer_params['schema'] = schema_slug
+        # restricted by schema ?
+        schema_slug = context.get('schema_slug')
+        if schema_slug is not None: 
+            layer_params['schema'] = schema_slug
 
-    items_layer = {
-        'url': reverse('ajax-newsitems-geojson'),
-        'params': layer_params,
-        'title': "News" ,
-        'visible': True
-    }
+        items_layer = {
+            'url': reverse('ajax-newsitems-geojson'),
+            'params': layer_params,
+            'title': "News" ,
+            'visible': True
+        }
     config['layers'].append(items_layer)
     config['baselayer_type'] = settings.MAP_BASELAYER_TYPE
     return simplejson.dumps(config, indent=2)
@@ -997,28 +1145,40 @@ def place_detail_overview(request, *args, **kwargs):
     schema_manager = get_schema_manager(request)
     context['breadcrumbs'] = breadcrumbs.place_detail_overview(context)
 
-    # Here, the goal is to get the latest nearby NewsItems for each
-    # schema. A naive way to do this would be to run the query once for
-    # each schema, but we improve on that by grabbing the latest 300
-    # items of ANY schema and hoping that several of the schemas include
-    # all of their recent items in that list. Then, for any remaining
-    # schemas, we do individual queries as a last resort.
-    # Note that we iterate over the 300 NewsItems as the outer loop rather
-    # than iterating over the schemas as the outer loop, because there are
-    # many more NewsItems than schemas.
-    s_list = SortedDict([(s.id, [s, [], 0]) for s in schema_manager.filter(is_special_report=False).order_by('plural_name')])
-    needed = set(s_list.keys())
-    newsitem_qs = NewsItem.objects.all()
-    for ni in newsitem_qs.order_by('-item_date', '-id')[:300]:
-        # Ordering by ID ensures consistency across page views.
-        s_id = ni.schema_id
-        if s_id in needed:
-            s_list[s_id][1].append(ni)
-            s_list[s_id][2] += 1
-            if s_list[s_id][2] == s_list[s_id][0].number_in_overview:
-                needed.remove(s_id)
+    schema_list = SortedDict([(s.id, s) for s in schema_manager.filter(is_special_report=False).order_by('plural_name')])
+    # needed = set(schema_list.keys())
 
-    # Mapping of schema id -> [schemafields].
+    # We actually want two lists of schemas, since we care whether
+    # they are news-like or future-event-like.
+    import copy
+    eventish_schema_list = copy.deepcopy(schema_list)
+    newsish_schema_list = copy.deepcopy(schema_list)
+    for s_id, schema in schema_list.items():
+        if schema.is_event:
+            del(newsish_schema_list[s_id])
+        else:
+            del(eventish_schema_list[s_id])
+
+    filterchain = FilterChain(request=request, context=context)
+    filterchain.add('location', context['place'])
+
+    # Distinguish between past news and upcoming events.
+    # With some preliminary date limiting too.
+    filterchain_news = filterchain.copy()
+    filterchain_news.add('date',
+                         today() - datetime.timedelta(days=90),
+                         today())
+
+    filterchain_events = filterchain.copy()
+    filterchain_events.add('date',
+                           today(),
+                           today() + datetime.timedelta(days=60))
+
+    # Ordering by ID ensures consistency across page views.
+    newsitem_qs = filterchain_news.apply().order_by('-item_date', '-id')
+    events_qs = filterchain_events.apply().order_by('item_date', 'id')
+
+    # Mapping of schema id -> [schemafields], for building Lookup charts.
     sf_dict = {}
     charted_lookups = SchemaField.objects.filter(
         is_lookup=True, is_charted=True, schema__is_public=True,
@@ -1027,24 +1187,30 @@ def place_detail_overview(request, *args, **kwargs):
     for sf in charted_lookups.order_by('schema__id', 'display_order'):
         sf_dict.setdefault(sf['schema_id'], []).append(sf)
 
+    # Now retrieve newsitems per schema.
     schema_groups, all_newsitems = [], []
-    for s, newsitems, _ in s_list.values():
-        if s.id in needed:
-            newsitems = list(newsitem_qs.filter(schema__id=s.id).order_by('-item_date', '-id')[:s.number_in_overview])
-        populate_schema(newsitems, s)
+    for schema in schema_list.values():
+        if schema.id in newsish_schema_list:
+            newsitems = newsitem_qs.filter(schema__id=schema.id)
+        elif schema.id in eventish_schema_list:
+            newsitems = events_qs.filter(schema__id=schema.id)
+        else:
+            raise RuntimeError("should never get here")
+        newsitems = list(newsitems[:s.number_in_overview])
+        populate_schema(newsitems, schema)
         schema_groups.append({
-            'schema': s,
+            'schema': schema,
             'latest_newsitems': newsitems,
             'has_newsitems': bool(newsitems),
-            'lookup_charts': sf_dict.get(s.id),
+            'lookup_charts': sf_dict.get(schema.id),
         })
         all_newsitems.extend(newsitems)
-    s_list = [s[0] for s in s_list.values()]
-    populate_attributes_if_needed(all_newsitems, s_list)
-    s_list = [s for s in s_list if s.allow_charting]
+    schema_list = schema_list.values()
+    populate_attributes_if_needed(all_newsitems, schema_list)
+    schema_list = [s for s in schema_list if s.allow_charting]
 
     context['schema_groups'] = schema_groups
-    context['filtered_schema_list'] = s_list
+    context['filtered_schema_list'] = schema_list
     context['bodyclass'] = 'place-detail-overview'
     if context['is_block']:
         context['bodyid'] = '%s-%s-%s' % (context['place'].street_slug,
@@ -1061,4 +1227,5 @@ def place_detail_overview(request, *args, **kwargs):
 def feed_signup(request, *args, **kwargs):
     context = get_place_info_for_request(request, *args, **kwargs)
     context['schema_list'] = get_schema_manager(request).filter(is_special_report=False).order_by('plural_name')
+    context['map_configuration'] = _preconfigured_map(context);
     return eb_render(request, 'db/feed_signup.html', context)
