@@ -44,7 +44,7 @@ def _first_not_false(*args):
 
 def proper_city(block):
     """
-    Returns the "proper" city for block.
+    Returns the "proper" city for block, as a string.
 
     This function is necessary because in the Block model there are
     two sides of the street, and the city on the left side could
@@ -57,10 +57,10 @@ def proper_city(block):
     should be in there. i.e., neither the left nor right side city is
     one of our metros or city within a multiple-city metro.
     """
-    from ebpub.db.models import Location
+    from ebpub.db.models import get_city_locations
     metro = get_metro()
     if metro['multiple_cities']:
-        cities = set([l.name.upper() for l in Location.objects.filter(location_type__slug=metro['city_location_type']).exclude(location_type__name__startswith='Unknown')])
+        cities = set([l.name.upper() for l in get_city_locations()])
     else:
         cities = set([metro['city_name'].upper()])
     # Determine the block's city, which because of blocks that
@@ -203,10 +203,10 @@ class Block(models.Model):
         max_length=255, db_index=True, blank=True,
         help_text='Name of city, UPPERCASE, on right side of street.')
 
-    left_state = USStateField(
+    left_state = USStateField(  # bad for i18n!
         db_index=True,
         help_text='US State abbreviation, UPPERCASE, on left side of street.')
-    right_state = USStateField(
+    right_state = USStateField(  # bad for i18n!
         db_index=True,
         help_text='US State abbreviation, UPPERCASE, on right side of street.')
 
@@ -261,7 +261,7 @@ class Block(models.Model):
         return ''.join(url)
 
     def url(self):
-        return urlresolvers.reverse('ebpub-block-timeline',
+        return urlresolvers.reverse('ebpub-block-recent',
                                     args=self._get_full_url_args())
 
     def _get_full_url_args(self):
@@ -332,26 +332,26 @@ class Block(models.Model):
 
         return (from_num <= number <= to_num), from_num, to_num
 
-    def _get_location(self):
+    @property
+    def location(self):
         return self.geom
-    location = property(_get_location)
 
-    def _get_city(self):
+    @property
+    def city(self):
         if not hasattr(self, '_city_cache'):
             self._city_cache = proper_city(self)
         return self._city_cache
-    city = property(_get_city)
 
-    def _get_state(self):
+    @property
+    def state(self):
         if self.left_state == self.right_state:
             return self.left_state
         else:
             return get_metro()['state']
-    state = property(_get_state)
 
-    def _get_zip(self):
+    @property
+    def zip(self):
         return self.left_zip
-    zip = property(_get_zip)
 
     def clean(self):
         """Enforce some constraints that depend on multiple fields.
@@ -366,21 +366,6 @@ class Block(models.Model):
             raise ValidationError(
                 "At least one of left_from_num, left_to_num, right_from_num, and/or right_to_num must be set to a non-empty, non-zero value")
 
-        # Try to fill in any missing numbers from the ones we got.
-        # Maybe we shouldn't be clever here?
-        if l_from is None:
-            logger.debug('left_from_num missing, guessing from other provided numbers')
-            l_from = _first_not_false(r_from, l_to, r_to)
-        if l_to is None:
-            logger.debug('left_to_num missing, guessing from other provided numbers')
-            l_to = _first_not_false(r_to)
-        if r_from is None:
-            logger.debug('right_from_num missing, guessing from other provided numbers')
-            r_from = _first_not_false(l_from, r_to, l_to)
-        if r_to is None:
-            logger.debug('right_to_num missing, guessing from other provided numbers')
-            r_to = _first_not_false(l_to)
-
         # Ensure we don't get the order wrong. Fixes #164
         if l_from > l_to:
             logger.debug('left_from_num %s cannot be greater than left_to_num %s, '
@@ -426,12 +411,15 @@ class Block(models.Model):
 
 
 class Street(models.Model):
-    street = models.CharField(max_length=255, db_index=True) # Always uppercase
+    street = models.CharField(max_length=255, db_index=True,
+                              help_text='Always uppercase.')
     pretty_name = models.CharField(max_length=255)
     street_slug = models.SlugField()
-    suffix = models.CharField(max_length=32, blank=True, db_index=True) # Always uppercase
-    city = models.CharField(max_length=255, db_index=True) # Always uppercase
-    state = USStateField(db_index=True) # Always uppercase
+    suffix = models.CharField(max_length=32, blank=True, db_index=True,
+                              help_text='Always uppercase.')
+    city = models.CharField(max_length=255, db_index=True,
+                            help_text='Always uppercase. City name, not slug.')
+    state = USStateField(db_index=True, help_text='Always uppercase.')  # bad for i18n!
 
     class Meta:
         db_table = 'streets'
@@ -567,7 +555,6 @@ class PlaceSynonymManager(models.Manager):
         If the given place name is already correctly spelled, then it's returned as-is.
         """        
         try:
-            from ebpub.geocoder.parser.parsing import normalize
             normalized_name = normalize(name)
             return self.get(normalized_name=normalized_name).place.normalized_name
         except self.model.DoesNotExist:
@@ -683,7 +670,7 @@ class Intersection(models.Model):
     postdir_b = models.CharField(max_length=2, blank=True, db_index=True) # eg., "SE"
     zip = models.CharField(max_length=10, db_index=True) # Possible Plus-4
     city = models.CharField(max_length=255, db_index=True) # Always uppercase
-    state = USStateField(db_index=True) # Always uppercase
+    state = USStateField(db_index=True) # Always uppercase. TODO: bad for i18n!
     location = models.PointField()
     objects = IntersectionManager()
 
